@@ -17,12 +17,10 @@ External resources:
 .. _GoogleGroup: http://groups.google.fr/group/guidata_guiqwt
 """
 
-__version__ = "2.0.2"
+__version__ = "2.0.4"
 
 # TODO: Add Python module hash utilities (for dependencies checking)
 # TODO: Investigate the qthelpers test failure (see after if __name__=='__main__')
-# TODO: Add support for PyQt6
-# TODO: Add support for PySide6
 
 # Dear (Debian, RPM, ...) package makers, please feel free to customize the
 # following path to module's data (images) and translations:
@@ -573,8 +571,9 @@ def install_translator(qapp):
         # Qt-specific translator
         qt_translator = QTranslator()
         paths = QLibraryInfo.location(QLibraryInfo.TranslationsPath)
-        if qt_translator.load("qt_" + locale, paths):
-            QT_TRANSLATOR = qt_translator  # Keep reference alive
+        for prefix in ("qt", "qtbase"):
+            if qt_translator.load(prefix + "_" + locale, paths):
+                QT_TRANSLATOR = qt_translator  # Keep reference alive
     if QT_TRANSLATOR is not None:
         qapp.installTranslator(QT_TRANSLATOR)
 
