@@ -13,11 +13,9 @@ UserConfig reader/writer objects
 (see guidata.hdf5io for another example of reader/writer)
 """
 
-import collections
+import collections.abc
 import datetime
 
-from qtpy.py3compat import is_unicode, PY3
-
 
 class GroupContext(object):
     """Group context object"""
@@ -89,7 +87,7 @@ class WriterMixin(object):
             self.write_int(val)
         elif isinstance(val, float):
             self.write_float(val)
-        elif is_unicode(val):
+        elif isinstance(val, str):
             self.write_unicode(val)
         elif isinstance(val, str):
             self.write_any(val)
@@ -106,7 +104,7 @@ class WriterMixin(object):
         elif isinstance(val, datetime.date):
             self.write_int(val.toordinal())
         elif hasattr(val, "serialize") and isinstance(
-            val.serialize, collections.Callable
+            val.serialize, collections.abc.Callable
         ):
             # The object has a DataSet-like `serialize` method
             val.serialize(self)
@@ -129,8 +127,7 @@ class UserConfigWriter(UserConfigIOHandler, WriterMixin):
     def write_unicode(self, val):
         self.write_any(val.encode("utf-8"))
 
-    if PY3:
-        write_unicode = write_str
+    write_unicode = write_str
 
     def write_none(self):
         self.write_any(None)
@@ -147,10 +144,9 @@ class UserConfigReader(UserConfigIOHandler):
 
     def read_unicode(self):
         val = self.read_any()
-        if is_unicode(val) or val is None:
+        if isinstance(val, str) or val is None:
             return val
         else:
             return self.read_str()
 
-    if PY3:
-        read_unicode = read_str
+    read_unicode = read_str
